@@ -1,30 +1,17 @@
 package App::gh;
 use warnings;
 use strict;
+our $VERSION = '0.26';
+use App::gh::Config;
+use App::gh::API;
 
-our $VERSION = '0.256';
-
-
-
-# XXX: move to othere place
-use App::gh::Utils;
-sub get_networks {
-    my $class = shift;
-    my $config = parse_config( ".git/config" );
-
-    my ( $name , $url ) = split( /\s+/ , qx( git remote -v | grep origin | grep push ) );
-
-    # git://github.com/miyagawa/Tatsumaki.git
-    if ( $url && ( $url =~ m{git://github.com/(.*?)/(.*?).git} 
-            || $url =~ m{git\@github.com:(.*?)/(.*?).git} ) ) {
-
-        my ($acc,$repo) = ($1,$2);
-        my $objs = api_request(qq(repos/show/$acc/$repo/network));
-        return $objs->{network};
-    }
+sub config {
+    return "App::gh::Config";
 }
 
-
+sub api {
+    return "App::gh::API";
+}
 
 __END__
 
